@@ -1273,6 +1273,29 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyInspectionSettings(self, request):
+        """设置巡检任务配置
+
+        :param request: Request instance for ModifyInspectionSettings.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyInspectionSettingsRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyInspectionSettingsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInspectionSettings", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInspectionSettingsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyInstanceBasic(self, request):
         """修改集群名称
 
@@ -1459,6 +1482,29 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifySLInstanceBasic(self, request):
+        """serverless hbase修改实例名称
+
+        :param request: Request instance for ModifySLInstanceBasic.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifySLInstanceBasicRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifySLInstanceBasicResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifySLInstanceBasic", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifySLInstanceBasicResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyUserManagerPwd(self, request):
         """修改用户密码（用户管理）
 
@@ -1552,7 +1598,7 @@ class EmrClient(AbstractClient):
 
 
     def ResizeDataDisks(self, request):
-        """云盘扩容
+        """云数据盘扩容
 
         :param request: Request instance for ResizeDataDisks.
         :type request: :class:`tencentcloud.emr.v20190103.models.ResizeDataDisksRequest`
