@@ -23,6 +23,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 年龄限制无法使用电子签服务，请联系客服咨询处理。
 FAILEDOPERATION_AGENOTACHIEVENORMALLEGAL = 'FailedOperation.AgeNotAchieveNormalLegal'
 
+# 套餐余额不足。
+FAILEDOPERATION_BALANCENOTENOUGH = 'FailedOperation.BalanceNotEnough'
+
 # 签署流程已有关联文档，请检查参数修改后重试。
 FAILEDOPERATION_FLOWHASDOCUMENT = 'FailedOperation.FlowHasDocument'
 
@@ -197,6 +200,9 @@ INVALIDPARAMETER_EMPTYPARAMS = 'InvalidParameter.EmptyParams'
 # 不合法的EndPoint，请检查修改后重试。
 INVALIDPARAMETER_ENDPOINT = 'InvalidParameter.EndPoint'
 
+# 不合法的合同过期时间
+INVALIDPARAMETER_FLOWAPPROVERDEADLINE = 'InvalidParameter.FlowApproverDeadline'
+
 # 不合法的签署流程回调链接，请修改后重试。
 INVALIDPARAMETER_FLOWCALLBACKURL = 'InvalidParameter.FlowCallbackUrl'
 
@@ -260,6 +266,9 @@ INVALIDPARAMETER_INVALIDVERIFYCHANNEL = 'InvalidParameter.InvalidVerifyChannel'
 # 不合法的跳转链接，请联系电子签客服添加链接白名单。
 INVALIDPARAMETER_JUMPURL = 'InvalidParameter.JumpUrl'
 
+# 关键字格式错误或者不存在。
+INVALIDPARAMETER_KEYWORD = 'InvalidParameter.Keyword'
+
 # Limit参数超出最大限制
 INVALIDPARAMETER_LIMIT = 'InvalidParameter.Limit'
 
@@ -386,6 +395,9 @@ MISSINGPARAMETER_FLOWID = 'MissingParameter.FlowId'
 # 未找到关键字配置信息，请检查控件传参，检查文件资源配置，并在修改后重试。
 MISSINGPARAMETER_KEYWORD = 'MissingParameter.KeyWord'
 
+# 参数缺失，企业名称和统一信用代码不能同时为空。
+MISSINGPARAMETER_ORGNAMEORUNIFORMSOCIALCREDITCODE = 'MissingParameter.OrgNameOrUniformSocialCreditCode'
+
 # 缺少机构ID参数。
 MISSINGPARAMETER_ORGANIZATIONID = 'MissingParameter.OrganizationId'
 
